@@ -9,8 +9,8 @@
 #' @param seed Random seed.  If 0, 'std::time(NULL)' is used.  Default
 #'   value "0" (integer).
 #' @param verbose Display informational messages and the full list of
-#'   parameters and timers at the end of execution.  Default value "FALSE"
-#'   (logical).
+#'   parameters and timers at the end of execution.  Default value
+#'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
 #' @return A list with several components:
 #' \item{output}{Matrix to save output samples in (numeric matrix).}
@@ -37,7 +37,7 @@
 gmm_generate <- function(input_model,
                          samples,
                          seed=NA,
-                         verbose=FALSE) {
+                         verbose=getOption("mlpack.verbose", FALSE)) {
   # Create parameters and timers objects.
   p <- CreateParams("gmm_generate")
   t <- CreateTimers()
@@ -54,10 +54,8 @@ gmm_generate <- function(input_model,
     SetParamInt(p, "seed", seed)
   }
 
-  if (verbose) {
-    EnableVerbose()
-  } else {
-    DisableVerbose()
+  if (!identical(verbose, FALSE)) {
+    SetParamBool(p, "verbose", verbose)
   }
 
   # Mark all output options as passed.
